# Speedcord
A simple discord API wrapper - without all the bullshit

We have a discord! Join us at https://discord.gg/yxrprWz

## Contributions
Some ideas of what we need in speedcord

- Automatically scale shards when we gain guilds
- Type more of the files (using .pyi files)
- Optimise the code
